pub struct VirtualPort { /* private fields */ }Expand description
VirtualPort simulates a serial port for testing purposes. It supports
setting various serial port parameters like baud rate, data bits, flow control,
parity, and stop bits. It also supports reading from and writing to buffers.
Port pair wiring diagram:
Port 1 Port 2 ┌─────┐ ┌─────┐ │ TXD ├──────────▶│ RXD │ │ RXD │◂──────────┤ TXD │ │ RTS ├──────────▶│ CTS │ │ CTS │◂──────────┤ RTS │ │ DTR ├─────────┬▶│ DSR │ │ │ └▶│ CD │ │ DSR │◂┬─────────┤ DTR │ │ CD │◂┘ │ │ │ RI ├───────────┤ RI │ └─────┘ └─────┘
Implementations
Sourceimpl VirtualPort
impl VirtualPort
Sourcepub fn loopback(baud_rate: u32, buffer_capacity: u32) -> Result<Self>
pub fn loopback(baud_rate: u32, buffer_capacity: u32) -> Result<Self>
Opens a single loopback virtual port with the specified baud rate.
Sourcepub fn pair(baud_rate: u32, buffer_capacity: u32) -> Result<(Self, Self)>
pub fn pair(baud_rate: u32, buffer_capacity: u32) -> Result<(Self, Self)>
Opens a pair of connected virtual ports with the specified baud rate. These ports can simulate a communication between two devices.
Sourcepub fn into_boxed(self) -> Box<dyn SerialPort>
pub fn into_boxed(self) -> Box<dyn SerialPort>
Boxes the instance as a SerialPort.
Sourcepub fn simulate_delay(&self) -> bool
pub fn simulate_delay(&self) -> bool
Returns whether transmission delay simulation is enabled.
Sourcepub fn set_simulate_delay(&mut self, value: bool)
pub fn set_simulate_delay(&mut self, value: bool)
Sets whether to simulate the transmission delay for reading operations.
Sourcepub fn noise_on_config_mismatch(&self) -> bool
pub fn noise_on_config_mismatch(&self) -> bool
Returns whether to simulate corrupted symbols if physical settings don’t match.
Sourcepub fn set_noise_on_config_mismatch(&mut self, value: bool)
pub fn set_noise_on_config_mismatch(&mut self, value: bool)
Sets whether to simulate corrupted symbols if physical settings don’t match.